package graph;
import java.util.*;

public class Edge implements Comparable {
    Map properties = new TreeMap();
    String label;
    double capacity;
    Node source,dest;

    /**
     *Returns the source node of the edge.
     *@return the source Node
     */
    public Node source() {
	return source;
    }

    /**
     *Returns the destination node of the edge.
     *@return the destination Node
     */
    public Node dest() {
	return dest;
    }

    /**
     *Initializes the Edge with given label and source and destination nodes.
     *@param label the label of the edge
     *@param src source Node of the edge
     *@param dst destination Node of the edge
     */
    public Edge(String label, Node src, Node dst) {
	properties.put("id",label);
	source = src;
	dest = dst;
    }
    /**
     *Initializes the Edge with given source and destination nodes.
     *@param src source Node of the edge
     *@param dst destination Node of the edge
     */
    public Edge(Node src, Node dst) {
	source = src;
	dest = dst;
    }

    public int compareTo(Object o) {
	return hashCode() - o.hashCode();
    }
    /**
     *Returns the label of the edge
     *@return a String containing the label of the edge or null, if the edge does not have one.
     */
    public String label() {
	return get("id");
    }
    /**
     *Sets the given property of the edge to given value
     *@param property a String containing property for which the value is set
     *@param value a String containing the new value for the property
     */
    public void set(String property, String value) {
	properties.put(property,value);
    }

    /**
     *Sets the given property of the edge to given value
     *@param property a String containing property for which the value is set
     *@param value an integer containing the new value for the property
     */
    public void setInt(String property, int value) {
	properties.put(property,String.valueOf(value));
    }

    /**
     *Sets the given property of the edge to given value
     *@param property a String containing property for which the value is set
     *@param value a double containing the new value for the property
     */
    public void setDouble(String property, double value) {
	properties.put(property,String.valueOf(value));
    }
    /**
     *Returns the value for the given property of the edge
     *@param property a String containing the requested property
     *@return a String containing the current value of the property, or null, if the property does not exist
     */
    public String get(String property) {
	return (String)properties.get(property);
    }

    /**
     *Returns the value for the given property of the edge
     *@param property a String containing the requested property
     *@return an integer containing the current value of the property, or -1, if the property does not exist
     */
    public int getInt(String property) throws NumberFormatException {
	return Integer.parseInt((String)properties.get(property));
    }

    /**
     *Returns the value for the given property of the edge
     *@param property a String containing the requested property
     *@return a double containing the current value of the property, or -1, if the property does not exist
     */
    public double getDouble(String property) throws NumberFormatException {
	return Double.parseDouble((String)properties.get(property));
    }
}
